@@ -72,7 +72,7 @@ enum {		// Window IDs
 	ID_CRQ_QEMONTH,
 	ID_CRQ_QEDAY,
 	ID_CRQ_DXCC,
-	ID_CRQ_SIGN,
+	ID_CRQ_TYPE,
 	ID_CRQ_CERT,
 	ID_CRQ_PW1,
 	ID_CRQ_PW2,
